@@ -1,4 +1,7 @@
-
+import sklearn
+import numpy
+import scipy
+import pandas
 
 
 def ABC(data):
@@ -706,7 +709,7 @@ def linear_elasticity (prices,Sales,present_price,cost_of_product):
   
   data_final={'Elasticity':Elasticity1,'optimum_price_profit':optimum_profit,
                        'optimum_price_revenue':optimum_revenue}
-
+  return data_final
 
 
 
